pub struct FlowLogStatusParameters {
pub target_resource_id: String,
}Expand description
Parameters that define a resource to query flow log and traffic analytics (optional) status.
Fields
target_resource_id: StringThe target resource where getting the flow log and traffic analytics (optional) status.
Implementations